@@ -12,7 +12,7 @@ Usage::
     session_client: PersonalizeRuntimeClient = session.client("personalize-runtime")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, List, TYPE_CHECKING
+from typing import Any, Dict, List, TYPE_CHECKING, Type
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_personalize_runtime.type_defs import (
     GetPersonalizedRankingResponseTypeDef,
@@ -24,21 +24,21 @@ __all__ = ("PersonalizeRuntimeClient",)
 
 
 class Exceptions:
-    ClientError: Boto3ClientError
-    InvalidInputException: Boto3ClientError
-    ResourceNotFoundException: Boto3ClientError
+    ClientError: Type[Boto3ClientError]
+    InvalidInputException: Type[Boto3ClientError]
+    ResourceNotFoundException: Type[Boto3ClientError]
 
 
 class PersonalizeRuntimeClient:
     """
-    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
+    [PersonalizeRuntime.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/personalize-runtime.html#PersonalizeRuntime.Client)
     """
 
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -49,14 +49,14 @@ class PersonalizeRuntimeClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.generate_presigned_url)
         """
 
     def get_personalized_ranking(
         self, campaignArn: str, inputList: List[str], userId: str, context: Dict[str, str] = None
     ) -> GetPersonalizedRankingResponseTypeDef:
         """
-        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
+        [Client.get_personalized_ranking documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_personalized_ranking)
         """
 
     def get_recommendations(
@@ -68,5 +68,5 @@ class PersonalizeRuntimeClient:
         context: Dict[str, str] = None,
     ) -> GetRecommendationsResponseTypeDef:
         """
-        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.27/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
+        [Client.get_recommendations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.32/reference/services/personalize-runtime.html#PersonalizeRuntime.Client.get_recommendations)
         """
